@@ -5,7 +5,7 @@
 ;; Author: Zajcev Evgeny <zevlg@yandex.ru>
 ;; Created: Thu Dec  4 16:32:11 MSK 2003
 ;; Keywords: xwem, xlib
-;; X-CVS: $Id: xwem-launcher.el,v 1.5 2004/05/12 16:14:32 lg Exp $
+;; X-CVS: $Id: xwem-launcher.el,v 1.6 2004/07/14 08:38:56 youngs Exp $
 
 ;; This file is part of XWEM.
 
@@ -36,9 +36,10 @@
 
 ;;; Code:
 
-(eval-and-compile
-;  (require 'completer)
-  (require 'comint))
+;(require 'completer)
+(require 'comint)
+(eval-when-compile
+  (require 'xlib-xlib))
 
 (autoload 'executable-find "executable")
 
@@ -53,7 +54,6 @@ Beep performed using \(xwem-play-sound 'ready\)."
   :type 'boolean
   :group 'xwem-launcher)
 
-;;;###autoload
 (defcustom xwem-launcher-function 'xwem-execute-program
   "Function to be used to execute external program."
   :type 'function
@@ -448,7 +448,6 @@ ARG passed as first argument to `xwem-make-frame-1'."
     (xwem-frame-select oframe))
   )
 
-;;;###autoload
 (defsubst xwem-launch (cmd)
   "Execute CMD using `xwem-launcher'."
   (funcall xwem-launcher-function cmd))
@@ -585,7 +584,7 @@ Prefix ARG is actually unused."
   "Popup menu."
   (xwem-interactive (list (X-Win-get-prop (X-Event-win xwem-last-xevent) 'ladock-action)))
 
-  (let (cls menu oldfrnum)
+  (let (cls menu)
     (mapc (lambda (cl)
             (when (string-match (cdr action) (xwem-hints-wm-command (xwem-cl-hints cl)))
               (setq cls (cons cl cls))))
