@@ -5,7 +5,7 @@
 ;; Author: Zajcev Evgeny <zevlg@yandex.ru>
 ;; Created: Mon Jan 12 13:14:32 MSK 2004
 ;; Keywords: xwem
-;; X-CVS: $Id: xwem-osd.el,v 1.2 2004/05/05 22:43:07 lg Exp $
+;; X-CVS: $Id: xwem-osd.el,v 1.3 2004/07/14 08:38:56 youngs Exp $
 
 ;; This file is part of XWEM.
 
@@ -79,8 +79,8 @@
 ;;; Code:
 
 (eval-when-compile
-  (require 'cl))
-
+  (require 'cl)
+  (require 'xlib-xlib))
 (require 'xlib-xshape)
 
 (defconst xwem-osd-instance-types '(text line dots arc rect)
