@@ -5,7 +5,7 @@
 ;; Author: Zajcev Evgeny <zevlg@yandex.ru>
 ;; Created: Thu Dec  4 17:42:12 MSK 2003
 ;; Keywords: xwem, xlib
-;; X-CVS: $Id: xwem-strokes.el,v 1.3 2004/05/11 15:14:06 youngs Exp $
+;; X-CVS: $Id: xwem-strokes.el,v 1.4 2004/07/14 08:38:56 youngs Exp $
 
 ;; This file is part of XWEM.
 
@@ -31,9 +31,11 @@
 ;; 
 
 ;;; Code:
-
-(eval-and-compile
-  (require 'strokes))
+(eval-when-compile
+  (require 'xwem-misc))
+(require 'strokes)
+(require 'xwem-compat)
+(require 'xwem-keyboard)
 
 (defgroup xwem-strokes nil
   "Group to customize XWEM strokes."
@@ -113,7 +115,6 @@ Look at `strokes-grid-resolution' for details."
   :group 'xwem-faces)
 
 ;; Stroke variables
-;;;###autoload
 (defvar xwem-strokes-keymap 
   (let ((map (make-sparse-keymap)))
     (set-keymap-default-binding map 'xwem-strokes-nocmd)
